==> rWikiPathways_1.0.5.zip: rWikiPathways/doc/rWikiPathways-and-BridgeDbR.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      source("https://bioconductor.org/biocLite.R")
#      biocLite("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"BridgeDbR" %in% installed.packages()){
#      source("https://bioconductor.org/biocLite.R")
#      biocLite("BridgeDbR")
#  }
#  library(BridgeDbR)

## --------------------------------------------------------------------------
#      orgNames <- listOrganisms()
#      orgNames

## --------------------------------------------------------------------------
#      unlist(lapply(orgNames,BridgeDbR::getOrganismCode))

## --------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Ensembl")

## --------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Entrez Gene")

## --------------------------------------------------------------------------
#      tnf.pathways <- findPathwayIdsByXref('TNF', getSystemCode('HGNC'))
#      tnf.pathways

## --------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('Ensembl'))

## --------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('ChEBI'))

## --------------------------------------------------------------------------
#      BridgeDbR::getFullName('Ce')

==> rWikiPathways_1.2.1.zip: rWikiPathways/doc/rWikiPathways-and-BridgeDbR.R <==
## ---- echo = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  eval=FALSE
)

## --------------------------------------------------------------------------
#  if(!"rWikiPathways" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("rWikiPathways")
#  }
#  library(rWikiPathways)
#  if(!"BridgeDbR" %in% installed.packages()){
#      if (!requireNamespace("BiocManager", quietly=TRUE))
#          install.packages("BiocManager")
#      BiocManager::install("BridgeDbR")
#  }
#  library(BridgeDbR)

## --------------------------------------------------------------------------
#      orgNames <- listOrganisms()
#      orgNames

## --------------------------------------------------------------------------
#      unlist(lapply(orgNames,BridgeDbR::getOrganismCode))

## --------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Ensembl")

## --------------------------------------------------------------------------
#      BridgeDbR::getSystemCode("Entrez Gene")

## --------------------------------------------------------------------------
#      tnf.pathways <- findPathwayIdsByXref('TNF', getSystemCode('HGNC'))
#      tnf.pathways

## --------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('Ensembl'))

## --------------------------------------------------------------------------
#      getXrefList('WP554', getSystemCode('ChEBI'))

## --------------------------------------------------------------------------
#      BridgeDbR::getFullName('Ce')
